text
stringlengths
2
99.9k
meta
dict
/* *********************************************************************** * * project: org.matsim.* * * * *********************************************************************** * * ...
{ "pile_set_name": "Github" }
keystore( name = "debug", properties = "debug.keystore.properties", store = "debug.keystore", visibility = [ "PUBLIC", ], )
{ "pile_set_name": "Github" }
#pragma once #include "AI/Monsters/ai_monster_squad.h" #include "AI/Monsters/ai_monster_squad_manager.h" #define TEMPLATE_SPECIALIZATION template <\ typename _Object\ > #define CStateMonsterAttackRunAbstract CStateMonsterAttackRun<_Object> TEMPLATE_SPECIALIZATION void CStateMonsterAttackRunAbstract::initialize() {...
{ "pile_set_name": "Github" }
PortSystem 1.0 name rootsh version 1.5.3 categories shells maintainers {toby @tobypeterson} description logging wrapper for shells long_description \ Rootsh is a wrapper for shells which logs all echoed \ keystrokes and terminal output to a file and/or to \ syslog. Its main purpo...
{ "pile_set_name": "Github" }
/* ============================================================ * QupZilla - WebKit based browser * Copyright (C) 2014 David Rosca <nowrep@gmail.com> * * This program is free software: you can redistribute it and/or modify * it under the terms of the GNU General Public License as published by * the Free Software Found...
{ "pile_set_name": "Github" }
/* Copyright The Kubernetes Authors. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, softw...
{ "pile_set_name": "Github" }
'use strict'; var Promise = require('./core.js'); module.exports = Promise; Promise.prototype['finally'] = function (f) { return this.then(function (value) { return Promise.resolve(f()).then(function () { return value; }); }, function (err) { return Promise.resolve(f()).then(function () { ...
{ "pile_set_name": "Github" }
using PetaPoco; using System; using System.Collections.Generic; using System.Linq; using Xms.Core.Data; using Xms.Data; using Xms.DataMapping.Abstractions; using Xms.DataMapping.Domain; using Xms.Infrastructure; using Xms.Infrastructure.Utility; using Xms.Localization.Abstractions; using Xms.Schema.Extensions; using X...
{ "pile_set_name": "Github" }
POST /vspx/custom_format.vspx HTTP/1.1 User-Agent: Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1) Opera 7.11 [en] Host: duple:8440 Accept: text/html, image/png, image/jpeg, image/gif, image/x-xbitmap, */*;q=0.1 Accept-Language: en;q=1.0,ru;q=0.9 Accept-Charset: windows-1252, utf-8, utf-16, iso-8859-1;q=0.6, *...
{ "pile_set_name": "Github" }
// RUN: %clang_cc1 -fcxx-exceptions -fexceptions -fsyntax-only -verify %s -std=c++11 struct S { virtual ~S(); void g() throw (auto(*)()->int); // Note, this is not permitted: conversion-declarator cannot have a trailing return type. // FIXME: don't issue the second diagnostic for this. operator auto(*)()->...
{ "pile_set_name": "Github" }
using System.Collections.Generic; namespace HotChocolate.Data.Sorting { public static class SortVisitorContextExtensions { public static void ReportError<T> (this ISortVisitorContext<T> context, IError error) => context.Errors.Add(error); public static T Get...
{ "pile_set_name": "Github" }
#!/bin/bash set -e set -o pipefail STARTUP_PATH=$(pwd) TMP_DIR_NAME=$(basename $0) USAGE_MESSAGE="USAGE: $0 <CLUSTER_NAMESPACE> <SQL_MASTER_ENDPOINT> <KNOX_ENDPOINT> [--install-extra-samples] [SQL_MASTER_PORT] [KNOX_PORT] To use basic authentication please set AZDATA_USERNAME and AZDATA_PASSWORD environment variables....
{ "pile_set_name": "Github" }
SUBROUTINE eomccsdtq_y3_11_2_2(d_a,k_a_offset,d_b,k_b_offset,d_c,k &_c_offset) C $Id$ C This is a Fortran77 program generated by Tensor Contraction Engine v.1.0 C Copyright (c) Battelle & Pacific Northwest National Laboratory (2002) C i2 ( h4 h11 h13 h16 )_vt + = 2 * Sum ( p7 ) * t ( p7 h16 )...
{ "pile_set_name": "Github" }
// Copyright (c) 2017 Google Inc. // // Licensed under the Apache License, Version 2.0 (the "License"); // you may not use this file except in compliance with the License. // You may obtain a copy of the License at // // http://www.apache.org/licenses/LICENSE-2.0 // // Unless required by applicable law or agreed to...
{ "pile_set_name": "Github" }
# Mustache Mustache files are compiled with Twitter's wonderful [hogan.js](https://github.com/twitter/hogan.js). This is a fantastic compiler that easily supports client-side templates and has very straightforward options and good compile speed. The options you can pass can be [found here](https://github.com/twitter/h...
{ "pile_set_name": "Github" }
#pragma warning disable CS1591 // Missing XML comment for publicly visible type or member using System; using System.Threading; using UnityEngine; using UnityEngine.Events; using UnityEngine.UI; namespace Cysharp.Threading.Tasks { public static partial class UnityAsyncExtensions { public static Async...
{ "pile_set_name": "Github" }
<?php /** * Hoa * * * @license * * New BSD License * * Copyright © 2007-2017, Hoa community. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions are met: * * Redistributions of source code must ...
{ "pile_set_name": "Github" }
# Ballerina Implementation Home Page URL: [ballerina/websub](https://ballerina.io/learn/api-docs/ballerina/websub.html) Source code repo URL(s) (optional): https://github.com/ballerina-lang/ballerina * [x] 100% open source implementation Programming Language(s): Ballerina Developer(s): [Ballerina](https://balleri...
{ "pile_set_name": "Github" }
// Copyright lowRISC contributors. // Licensed under the Apache License, Version 2.0, see LICENSE for details. // SPDX-License-Identifier: Apache-2.0 // // Register slice conforming to Comportibility guide. module prim_subreg_ext #( parameter int unsigned DW = 32 ) ( input re, input we, input...
{ "pile_set_name": "Github" }
/***************************************************************************/ /* */ /* cf2hints.h */ /* */ /* Ad...
{ "pile_set_name": "Github" }
# Lista de Cursos Gratuitos em Polonês Lista criada em 27-07-2019. Entre no grupo do Telegram para receber avisos sobre as atualizações das listas. No grupo serão compartilhados cupons de desconto disponibilizados por alguns instrutores da Udemy. Entre no grupo agora mesmo: [Grupo no Telegram](http://bit.ly...
{ "pile_set_name": "Github" }
{ "pile_set_name": "Github" }
/* * Copyright 2019 Web3 Labs Ltd. * * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with * the License. You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agreed to in w...
{ "pile_set_name": "Github" }
<!doctype html> <html lang="en"> <head> <meta charset="utf-8"> <title>jQuery UI Resizable - Default functionality</title> <link rel="stylesheet" href="../../themes/base/all.css"> <script src="../../external/jquery/jquery.js"></script> <script src="../../ui/core.js"></script> <script src="../../ui/widget.js"></scr...
{ "pile_set_name": "Github" }
------------------------ Gc收集器 | ------------------------ # 收集算法是内存回收的方法论, 收集器则是实现了 # jvm规范对收集器怎么去实现, 没有任何规定, 所以不同厂家, 不同版本的可能不一样 # GC收集器目前主要的有 * 新生代收集器 Serial ParNew Parallel Scavenge * 老年代收集器 Concurrent Mark Sweep(CMS) Parallel Old Serial Old(MSC) * 全堆收集器 Garbage First(G1) * 不同...
{ "pile_set_name": "Github" }
<!DOCTYPE html> <html lang="en"> <head> <meta charset="utf-8"> <title>ExampleModule</title> <link rel="stylesheet" href="http:&#x2F;&#x2F;yui.yahooapis.com&#x2F;3.7.0&#x2F;build&#x2F;cssgrids&#x2F;cssgrids-min.css"> <link rel="stylesheet" href="..&#x2F;assets/vendor/prettify/prettify-min.css"> <link...
{ "pile_set_name": "Github" }
/* * Copyright (c) 2018, 2019, Oracle and/or its affiliates. All rights reserved. * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER. * * This code is free software; you can redistribute it and/or modify it * under the terms of the GNU General Public License version 2 only, as * published by the Free ...
{ "pile_set_name": "Github" }
<%@ page language="java" contentType="text/html; charset=ISO-8859-1" pageEncoding="ISO-8859-1"%> <!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd"> <html> <head> <meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"> <title>Local File Inclusion Test...
{ "pile_set_name": "Github" }
import torch import numpy as np import matplotlib.pyplot as plt import matplotlib.patches as patches from transforms3d.euler import euler2mat from skimage.io import imsave def visualize_bounding_box(rgb, corners_pred, corners_targets=None, centers_pred=None, centers_targets=None, save=False, save_fn=None): ''' ...
{ "pile_set_name": "Github" }
/* * Licensed to the Apache Software Foundation (ASF) under one * or more contributor license agreements. See the NOTICE file * distributed with this work for additional information * regarding copyright ownership. The ASF licenses this file * to you under the Apache License, Version 2.0 (the * "License"); you ...
{ "pile_set_name": "Github" }
// // TDFMockResourceImageFetcher.h // DFImageManager // // Created by Alexander Grebenyuk on 11/07/15. // Copyright (c) 2015 Alexander Grebenyuk. All rights reserved. // #import "DFImageManagerKit.h" #import <Foundation/Foundation.h> extern NSString *TDFMockFetcherDidStartOperationNotification; @interface TDFMo...
{ "pile_set_name": "Github" }
/* * Copyright (C) 2012, 2013 Apple Inc. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions * are met: * 1. Redistributions of source code must retain the above copyright * notice, this list of condit...
{ "pile_set_name": "Github" }
#!/bin/bash heapsize=4096 TCID="ion_test.sh" errcode=0 # Kselftest framework requirement - SKIP code is 4. ksft_skip=4 run_test() { heaptype=$1 ./ionapp_export -i $heaptype -s $heapsize & sleep 1 ./ionapp_import if [ $? -ne 0 ]; then echo "$TCID: heap_type: $heaptype - [FAIL]" errcode=1 else echo "$TCID:...
{ "pile_set_name": "Github" }
package hcldec import ( "github.com/hashicorp/hcl/v2" "github.com/zclconf/go-cty/cty" ) func decode(body hcl.Body, blockLabels []blockLabel, ctx *hcl.EvalContext, spec Spec, partial bool) (cty.Value, hcl.Body, hcl.Diagnostics) { schema := ImpliedSchema(spec) var content *hcl.BodyContent var diags hcl.Diagnostic...
{ "pile_set_name": "Github" }
fileFormatVersion: 2 guid: 6481d171179ace74495504668c11206c timeCreated: 1473765592 licenseType: Pro NativeFormatImporter: userData: assetBundleName: assetBundleVariant:
{ "pile_set_name": "Github" }
// The MIT License (MIT) // // Copyright (c) 2015, 2016 Arian Fornaris // // Permission is hereby granted, free of charge, to any person obtaining a // copy of this software and associated documentation files (the // "Software"), to deal in the Software without restriction, including // without limitation the ri...
{ "pile_set_name": "Github" }
// Copyright 2016 The Draco Authors. // // Licensed under the Apache License, Version 2.0 (the "License"); // you may not use this file except in compliance with the License. // You may obtain a copy of the License at // // http://www.apache.org/licenses/LICENSE-2.0 // // Unless required by applicable law or agree...
{ "pile_set_name": "Github" }
_ _ ____ _ ___| | | | _ \| | / __| | | | |_) | | | (__| |_| | _ <| |___ \___|\___/|_| \_\_____| TODO Things to do in project cURL. Please tell us wh...
{ "pile_set_name": "Github" }
136b240c0082461b206b32c9f7943b91b1eafeda
{ "pile_set_name": "Github" }
--- title: "Streamlining React Elements" author: [sebmarkbage] date: 2015-02-24 11:00 --- React v0.13 is right around the corner and so we wanted to discuss some upcoming changes to ReactElement. In particular, we added several warnings to some esoteric use cases of ReactElement. There are no runtime behavior changes ...
{ "pile_set_name": "Github" }
#!/bin/bash # description: system-wide syscall counts # args: [comm] if [ $# -gt 0 ] ; then if ! expr match "$1" "-" > /dev/null ; then comm=$1 shift fi fi perf script $@ -s "$PERF_EXEC_PATH"/scripts/python/syscall-counts.py $comm
{ "pile_set_name": "Github" }
using GridBlazorClientSide.Shared.Models; using Microsoft.EntityFrameworkCore; using System; using System.Linq; using System.Threading.Tasks; namespace GridBlazorClientSide.Server.Models { public class EmployeeRepository : SqlRepository<Employee>, IEmployeeRepository { public EmployeeRepository(Northw...
{ "pile_set_name": "Github" }
<?php /* * Copyright 2007-2017 Charles du Jeu - Abstrium SAS <team (at) pyd.io> * This file is part of Pydio. * * Pydio is free software: you can redistribute it and/or modify * it under the terms of the GNU Affero General Public License as published by * the Free Software Foundation, either version 3 of the Lice...
{ "pile_set_name": "Github" }
// Copyright (c) .NET Foundation. All rights reserved. // Licensed under the Apache License, Version 2.0. See License.txt in the project root for license information. using System; using System.Linq; using System.Reflection; using System.Runtime.CompilerServices; namespace Microsoft.Extensions.Internal.LE { inte...
{ "pile_set_name": "Github" }
<!doctype html> <html lang="en"> <head> <meta charset="utf-8"> <title>jQuery UI Resizable - Default functionality</title> <link rel="stylesheet" href="../../themes/base/jquery.ui.all.css"> <script src="../../jquery-1.9.1.js"></script> <script src="../../ui/jquery.ui.core.js"></script> <script src="../../ui/jquery...
{ "pile_set_name": "Github" }
<?php namespace CodeIgniter\Helpers; final class DateHelperTest extends \CodeIgniter\Test\CIUnitTestCase { private $name; private $value; private $expire; private $response; protected function setUp(): void { parent::setUp(); helper('date'); } //----------------------------------------------------------...
{ "pile_set_name": "Github" }
# The MIT License # # Italian localization plugin for Jenkins # Copyright © 2020 Alessandro Menti # # Permission is hereby granted, free of charge, to any person obtaining a copy # of this software and associated documentation files (the "Software"), to deal # in the Software without restriction, including without limi...
{ "pile_set_name": "Github" }
Array3d v(2,3,4), w(4,2,3); cout << v.min(w) << endl;
{ "pile_set_name": "Github" }
package org.json; /* Copyright (c) 2002 JSON.org Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, ...
{ "pile_set_name": "Github" }
require 'strscan' require 'digest/sha1' require 'sass/tree/node' require 'sass/tree/root_node' require 'sass/tree/rule_node' require 'sass/tree/comment_node' require 'sass/tree/prop_node' require 'sass/tree/directive_node' require 'sass/tree/variable_node' require 'sass/tree/mixin_def_node' require 'sass/tree/mixin_nod...
{ "pile_set_name": "Github" }
#define CUDA_KERNEL_LOOP(i, n) \ for (int i = blockIdx.x * blockDim.x + threadIdx.x; \ i < (n); \ i += blockDim.x * gridDim.x) #define INDEX(b,c,h,w,channels,height,width) ((b * channels + c) * height + h) * width+ w extern "C" __global__ ...
{ "pile_set_name": "Github" }
#define COMMON_DIGEST_FOR_OPENSSL 1 #include <CommonCrypto/CommonDigest.h> #define SHA1_BLOCK_LENGTH CC_SHA1_BLOCK_BYTES #define SHA1_DIGEST_LENGTH CC_SHA1_DIGEST_LENGTH #define SHA1_CTX CC_SHA1_CTX static DEFINE_UPDATE_FUNC_FOR_UINT(SHA1) static DEFINE_FINISH_FUNC_FROM_FINAL(SHA1) #undef SHA1_Update #undef SHA1_Fi...
{ "pile_set_name": "Github" }
# macos-lib.pl # Quota functions for OSX # XXX checking if on/off # quotas_init() sub quotas_init { if (&has_command("quotaon") && &has_command("quotaoff")) { return undef; } else { return "The quotas programs do not appear to be installed on ". "your system\n"; } } # quotas_supported() # Returns 1 for us...
{ "pile_set_name": "Github" }
import pytest from awx.api.versioning import reverse from awx.main.models import Project @pytest.fixture def organization_resource_creator(organization, user): def rf(users, admins, job_templates, projects, inventories, teams): # Associate one resource of every type with the organization for i ...
{ "pile_set_name": "Github" }
{ "nickname": "haohao", "age": 18 }
{ "pile_set_name": "Github" }
*cmdline.txt* Nvim VIM REFERENCE MANUAL by Bram Moolenaar *Cmdline-mode* *Command-line-mode* *Cmdline* Command-line mode *cmdline* *Command-line* *mode-cmdline* *:* Command-line mode is used to enter Ex commands (":"), search patterns ("/" and "?"), and filter commands ("!"). Basic command line edit...
{ "pile_set_name": "Github" }
class ServiceMap constructor: -> @remotes = Object.create null @count = 0 end: -> for remoteId, remote of @remotes remote.end() @remotes = Object.create null @count = 0 return insert: (remoteId, socket) -> if @remotes[remoteId] throw new Error "Remote ID #{remoteId} is al...
{ "pile_set_name": "Github" }
BEGIN_COM_MAP(COuter1) COM_INTERFACE_ENTRY_AGGREGATE(__uuidof(IAgg), m_punkAgg) END_COM_MAP()
{ "pile_set_name": "Github" }
 /*=================================================================================== * * Copyright (c) Userware (OpenSilver.net, CSHTML5.com) * * This file is part of both the OpenSilver Simulator (https://opensilver.net), which * is licensed under the MIT license (https://opensource.org/licenses/MIT),...
{ "pile_set_name": "Github" }
1 8 64 1 14 16 64 test @
{ "pile_set_name": "Github" }
#ifndef _SHA1_H #define _SHA1_H #ifdef __cplusplus extern "C" { #endif #ifndef _STD_TYPES #define _STD_TYPES #define uchar unsigned char #define uint unsigned int #define ulong unsigned long int #endif typedef struct { ulong total[2]; ulong state[5]; uchar buffer[64]; } sha1_context; /* * Core...
{ "pile_set_name": "Github" }
<?xml version="1.0"?> <ZopeData> <record id="1" aka="AAAAAAAAAAE="> <pickle> <global name="ProxyField" module="Products.ERP5Form.ProxyField"/> </pickle> <pickle> <dictionary> <item> <key> <string>delegated_list</string> </key> <value> <list/> ...
{ "pile_set_name": "Github" }
function(boost_modular_headers) cmake_parse_arguments(_bm "" "SOURCE_PATH" "" ${ARGN}) if(NOT DEFINED _bm_SOURCE_PATH) message(FATAL_ERROR "SOURCE_PATH is a required argument to boost_modular_headers.") endif() message(STATUS "Packaging headers") file( COPY ${_bm_SOURCE_...
{ "pile_set_name": "Github" }
/** * Solarized Light theme for reveal.js. * Author: Achim Staebler */ // Default mixins and settings ----------------- @import "../template/mixins"; @import "../template/settings"; // --------------------------------------------- // Include theme-specific fonts @import url(../../lib/font/league-gothic/league-g...
{ "pile_set_name": "Github" }
// Copyright 2015 The Chromium Authors. All rights reserved. // Use of this source code is governed by a BSD-style license that can be // found in the LICENSE file. #include "base/trace_event/heap_profiler_stack_frame_deduplicator.h" #include <inttypes.h> #include <stddef.h> #include <string> #include <utility> #in...
{ "pile_set_name": "Github" }
# frozen_string_literal: true # AsyncableJobMessaging handles the decision-making around how and whether events in the # lifecycle of an async job triggers sending a message to the user's inbox. class AsyncableJobMessaging FAILING_TIME_BEFORE_MESSAGING = 1.day.freeze attr_reader :job, :user def initialize(job:...
{ "pile_set_name": "Github" }
/* * Licensed to the Apache Software Foundation (ASF) under one or more * contributor license agreements. See the NOTICE file distributed with * this work for additional information regarding copyright ownership. * The ASF licenses this file to You under the Apache License, Version 2.0 * (the "License"); you may ...
{ "pile_set_name": "Github" }
package com.duckduckgo.mobile.android.events.deleteEvents; public class DeleteStoryInHistoryEvent extends DeleteEvent { public String feedObjectId; public DeleteStoryInHistoryEvent(String feedObjectId){ this.feedObjectId = feedObjectId; } }
{ "pile_set_name": "Github" }
angular.module("ngLocale", [], ["$provide", function($provide) { var PLURAL_CATEGORY = {ZERO: "zero", ONE: "one", TWO: "two", FEW: "few", MANY: "many", OTHER: "other"}; $provide.value("$locale", { "DATETIME_FORMATS": { "AMPMS": { "0": "\u043f\u0440. \u043e\u0431.", "1": "\u0441\u043b. \u043e\u0431." ...
{ "pile_set_name": "Github" }
package com.yugabyte.yw.common;// Copyright (c) YugaByte, Inc. import com.google.inject.Singleton; import com.google.inject.Inject; import java.io.InputStream; import org.yaml.snakeyaml.Yaml; import org.yaml.snakeyaml.constructor.CustomClassLoaderConstructor; @Singleton public class YamlWrapper { private final pla...
{ "pile_set_name": "Github" }
[![Stories in Ready](https://badge.waffle.io/dynosrc/dynosrc.png?label=ready)](https://waffle.io/dynosrc/dynosrc) [![NPM](https://nodei.co/npm/dynosrc.png?downloads=true&stars=true)](https://nodei.co/npm/dynosrc/) # [DynoSrc](http://www.dynosrc.com) DynoSRC is a general solution for efficiently delivering JS resour...
{ "pile_set_name": "Github" }
from pyrevit import forms from pyrevit import revit, DB class ViewTemplateToPurge(forms.TemplateListItem): @property def name(self): return self.item.Name viewlist = DB.FilteredElementCollector(revit.doc)\ .OfClass(DB.View)\ .WhereElementIsNotElementType()\ .To...
{ "pile_set_name": "Github" }
<?php /** * Copyright (c) UNA, Inc - https://una.io * MIT License - https://opensource.org/licenses/MIT * * @defgroup UnaStudioView UNA Studio Representation classes * @ingroup UnaStudio * @{ */ defined('BX_DOL') or die('hack attempt'); class BxTemplStudioGrid extends BxBaseStudioGrid { function __co...
{ "pile_set_name": "Github" }
<?php require 'includes/html/graphs/common.inc.php'; $rrd_options .= " COMMENT:' Min Last Max\\n'"; $sensor['sensor_descr_fixed'] = rrdtool_escape($sensor['sensor_descr'], 23); $rrd_options .= " DEF:sensor=$rrd_filename:sensor:AVERAGE"; $rrd_options .= " DEF:sensor_max=$rrd_filename:...
{ "pile_set_name": "Github" }
<?php declare(strict_types=1); /* * This file is part of the tenancy/tenancy package. * * Copyright Tenancy for Laravel * * For the full copyright and license information, please view the LICENSE * file that was distributed with this source code. * * @see https://tenancy.dev * @see https://github.com/tenancy...
{ "pile_set_name": "Github" }
# Copied from Dynmap. With thanks to Mike Primm 1 133 129 118 255 111 108 98 255 93 90 82 255 111 108 98 255 2 60 113 17 255 50 94 14 255 42 79 12 255 50 94 14 255 3 103 83 51 255 86 69 43 255 72 58 36 255 86 69 43 255 3:2 122 87 57 255 97 69 45 255 61 43 28 255 48 34 22 255 4 118 112 96 255 98 93 80 255 82 78 67 255 9...
{ "pile_set_name": "Github" }
/* * Copyright (C) 2015 Amarula Solutions B.V. * * This file is dual-licensed: you can use it either under the terms * of the GPL or the X11 license, at your option. Note that this dual * licensing only applies to this file, and not this project as a * whole. * * a) This file is free software; you can redistri...
{ "pile_set_name": "Github" }
/* * Copyright 2016- huaxz <huaxz1986@163.com> * * This program is free software: you can redistribute it and/or modify * it under the terms of the GNU General Public License as published by * the Free Software Foundation, either version 2 of the License, or * (at your option) any later version. * * This progra...
{ "pile_set_name": "Github" }
1.0.5 * Added placeholder for textinput * Fixed a crasher when resizing a tab container * Icon can now be loaded from memory * Bitmap can be converted to icons using `Bitmap::copy_as_icon` * Systray pop up menu now closes when you click outside of them * Embedded image loading functions (`EmbedResource::image`, `Embed...
{ "pile_set_name": "Github" }
{ "_args": [ [ { "raw": "babel-plugin-transform-async-generator-functions@^6.22.0", "scope": null, "escapedName": "babel-plugin-transform-async-generator-functions", "name": "babel-plugin-transform-async-generator-functions", "rawSpec": "^6.22.0", "spec": ">=6...
{ "pile_set_name": "Github" }
#include "LightDefs.hlsli" #include "LightingModel.hlsli" #include "EnvAmbient.hlsli" #include <ShadowsOld/Csm.hlsli> #include <Postprocess/PostprocessBase.hlsli> #include <GBuffer/GBuffer.hlsli> #include <VertexTransformations.hlsli>
{ "pile_set_name": "Github" }
#include <linux/mm.h> #include <linux/file.h> #include <linux/fdtable.h> #include <linux/fs_struct.h> #include <linux/mount.h> #include <linux/ptrace.h> #include <linux/slab.h> #include <linux/seq_file.h> #include "internal.h" /* * Logic: we've got two memory sums for each process, "shared", and * "non-shared". Sha...
{ "pile_set_name": "Github" }
<article id="post-0" class="<?php hybrid_entry_class(); ?>"> <header class="entry-header"> <h1 class="entry-title"><?php __( 'Nothing found', 'bearded' ); ?></h1> </header> <div class="entry-content"> <p><?php _e( 'Apologies, but no entries were found.', 'bearded' ); ?></p> </div><!-- .entry-content --...
{ "pile_set_name": "Github" }
/* Copyright 2016 The Kubernetes Authors. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, ...
{ "pile_set_name": "Github" }
// This file is part of CPAchecker, // a tool for configurable software verification: // https://cpachecker.sosy-lab.org // // SPDX-FileCopyrightText: 2007-2020 Dirk Beyer <https://www.sosy-lab.org> // // SPDX-License-Identifier: Apache-2.0 #include <stdlib.h> #include <stdio.h> struct node { int* ptr; }; int main...
{ "pile_set_name": "Github" }
// // Generated by class-dump 3.5 (64 bit) (Debug version compiled Jun 9 2015 22:53:21). // // class-dump is Copyright (C) 1997-1998, 2000-2001, 2004-2014 by Steve Nygard. // #import <objc/NSObject.h> @class NSArray; @interface MBPortScanner : NSObject { NSArray *_interfaceArray; } - (void).cxx_destruc...
{ "pile_set_name": "Github" }
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "https://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"> <html xmlns="http://www.w3.org/1999/xhtml"> <head> <meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/> <meta http-equiv="X-UA-Compatible" content="IE=9"/> <meta name="generator" co...
{ "pile_set_name": "Github" }
require 'spec_helper' require 'ronin/campaign' describe Campaign do describe "targets?" do pending "needs specs" end describe "#target!" do pending "needs specs" end end
{ "pile_set_name": "Github" }
{ "name": "Kun the Forgotten King", "baseManaCost": 10, "type": "MINION", "baseAttack": 7, "baseHp": 7, "heroClass": "DRUID", "rarity": "LEGENDARY", "description": "Choose One - Gain 10 Armor; or Refresh your Mana Crystals.", "options": [ { "description": "Gain 10 Armor", "spell": { "class": "BuffH...
{ "pile_set_name": "Github" }
<?php /** * Zend Framework * * LICENSE * * This source file is subject to the new BSD license that is bundled * with this package in the file LICENSE.txt. * It is also available through the world-wide-web at this URL: * http://framework.zend.com/license/new-bsd * If you did not receive a copy of the license an...
{ "pile_set_name": "Github" }
## 一个笑话 - { 第2018-10-31期 } </hr> ### :jack_o_lantern: { 第1档 } 二到没治了 第一次去学校医院是因为发烧,医生大妈二话不说递给我一根体温计,我也二话不说就含在了嘴里……<br/><br/>  大妈看了我一眼,温柔地说道:“腋下。”<br/><br/>  我想了想,还是听话地叫了声:“耶!” ### :jack_o_lantern: { 第2档 } 毕竟游戏和命比起来 A:如果你在玩游戏女朋友给你打电话,让你陪他逛街,你会去吗?<br/><br/>  B:这还问吗,肯定会毫不犹豫的退游戏。<br/><br/>  A:你这种人不多了啊!<br/><br/>  B:是的,毕竟...
{ "pile_set_name": "Github" }
// license:BSD-3-Clause // copyright-holders:Mariusz Wojcieszek /* Photon IK-3 system Driver by Mariusz Wojcieszek Russian arcade system based on ZX Spectrum home computer clone "Leningrad-1". Changes are: - ROM bank switching added - original IO addressing replaced by: A7 A0 0 0 R...
{ "pile_set_name": "Github" }
import { browser, by, element } from 'protractor'; export class AppPage { navigateTo() { return browser.get('/'); } getTitleText() { return element(by.css('app-root h1')).getText(); } }
{ "pile_set_name": "Github" }
/* Flot plugin for adding the ability to pan and zoom the plot. Copyright (c) 2007-2013 IOLA and Ole Laursen. Licensed under the MIT license. The default behaviour is double click and scrollwheel up/down to zoom in, drag to pan. The plugin defines plot.zoom({ center }), plot.zoomOut() and plot.pan( offset ) so you ea...
{ "pile_set_name": "Github" }
/* * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved. */ /* * Licensed to the Apache Software Foundation (ASF) under one or more * contributor license agreements. See the NOTICE file distributed with * this work for additional information regarding copyright ownership. * The ASF licenses th...
{ "pile_set_name": "Github" }
/* * This file is part of the Soletta™ Project * * Copyright (C) 2015 Intel Corporation. All rights reserved. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apach...
{ "pile_set_name": "Github" }
// GENERATED package com.fkorotkov.openshift import io.fabric8.openshift.api.model.DeploymentConfigStatus as model_DeploymentConfigStatus import io.fabric8.openshift.api.model.DeploymentDetails as model_DeploymentDetails fun model_DeploymentConfigStatus.`details`(block: model_DeploymentDetails.() -> Unit = {}) { ...
{ "pile_set_name": "Github" }
<?xml version="1.0" encoding="utf-8"?> <string xmlns="http://tempuri.org/">{ "Info": [ { "IsSuccess": "True", "InAddress": "屏東縣屏東市中華路61-1號", "InSRS": "EPSG:4326", "InFuzzyType": "[單雙號機制]+[最近門牌號機制]", "InFuzzyBuffer": "0", "InIsOnlyFullMatch": "False", "InIsLockCo...
{ "pile_set_name": "Github" }
class A {a(){};b(){};}
{ "pile_set_name": "Github" }
<resources> <string name="app_name">CustomBroadcastPermissions</string> </resources>
{ "pile_set_name": "Github" }